"""General-use classes to interact with the CodeStarNotifications service through CloudFormation.

See Also:
    `AWS developer guide for CodeStarNotifications
    <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codestarnotifications as _raw

# noinspection PyUnresolvedReferences
from .._raw.codestarnotifications import *
