"""General-use classes to interact with the AccessAnalyzer service through CloudFormation.

See Also:
    `AWS developer guide for AccessAnalyzer
    <https://aws.amazon.com/iam/features/analyze-access/>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import accessanalyzer as _raw

# noinspection PyUnresolvedReferences
from .._raw.accessanalyzer import *
