"""General-use classes to interact with the CodeStar service through CloudFormation.

See Also:
    `AWS developer guide for CodeStar
    <https://docs.aws.amazon.com/codestar/latest/userguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codestar as _raw

# noinspection PyUnresolvedReferences
from .._raw.codestar import *
