"""Raw representations of every data type in the AWS AccessAnalyzer service.

See Also:
    `AWS developer guide for AccessAnalyzer
    <https://aws.amazon.com/iam/features/analyze-access/>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = ["Analyzer", "AnalyzerProperties"]


@attrs(**ATTRSCONFIG)
class AnalyzerProperties(ResourceProperties):
    AnalyzerName = attrib(default=None)
    ArchiveRules = attrib(default=None)
    Tags = attrib(default=None)
    Type = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Analyzer(Resource):
    """A Analyzer for AccessAnalyzer.

    See Also:
        `AWS Cloud Formation documentation for Analyzer
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html>`_
    """

    RESOURCE_TYPE = "AWS::AccessAnalyzer::Analyzer"

    Properties: AnalyzerProperties = attrib(
        factory=AnalyzerProperties,
        converter=create_object_converter(AnalyzerProperties),
    )
