"""General-use classes to interact with the LakeFormation service through CloudFormation.

See Also:
    `AWS developer guide for LakeFormation
    <https://docs.aws.amazon.com/lake-formation/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import lakeformation as _raw

# noinspection PyUnresolvedReferences
from .._raw.lakeformation import *
