"""General-use classes to interact with the MediaConvert service through CloudFormation.

See Also:
    `AWS developer guide for MediaConvert
    <http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import mediaconvert as _raw

# noinspection PyUnresolvedReferences
from .._raw.mediaconvert import *
