"""General-use classes to interact with the IoTEvents service through CloudFormation.

See Also:
    `AWS developer guide for IoTEvents
    <https://docs.aws.amazon.com/iotevents/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iotevents as _raw

# noinspection PyUnresolvedReferences
from .._raw.iotevents import *
