"""General-use classes to interact with the EventSchemas service through CloudFormation.

See Also:
    `AWS developer guide for EventSchemas
    <https://docs.aws.amazon.com/eventbridge/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import eventschemas as _raw

# noinspection PyUnresolvedReferences
from .._raw.eventschemas import *
